# Prompt the user for their choice
Write-Host "Do you want to save the updated files in the 'DD1' folder, overwrite the original files, or exit?"
Write-Host "(1) Save the updated profiles in DD1 folder"
Write-Host "(2) Overwrite the existing files"
Write-Host "(3) Exit"
$choice = Read-Host

if ($choice -eq "3")
{
  Write-Host "Exiting the script."
  exit 0
}


# Loop over .pws files in the current directory
Get-ChildItem -File -Filter "*.pws" | ForEach-Object {
  $file = $_

  # Read the content of the file as a single string
  $content = Get-Content $file -Raw

  # Use regex to find the key "FF" and its value
  $regex = '<FF>([0-9]{2,3})<\/FF>'
  if ($content -match $regex)
  {
    $key_value = [int]$matches[1]
    $new_value = [Math]::Floor($key_value * 1.25)  # Multiply by 1.25 and round down

    # Replace the old value with the new value
    $updated_content = $content -replace $regex, "<FF>$new_value</FF>"

    if ($choice -eq "1")
    {

      # Create the 'DD1' folder if it doesn't exist
      if (-not (Test-Path "DD1" -PathType Container))
      {
        New-Item -ItemType Directory -Path "DD1"
      }
      # Save the updated content to a new file in 'DD1' folder with "updated" after the extension
      $newFileName = Join-Path "DD1" ($file.BaseName + "_DD1" + $file.Extension)
      Set-Content -Path $newFileName -Value $updated_content -NoNewline
      Write-Host "Updated: $newFileName"
    } elseif ($choice -eq "2")
    {
      # Overwrite the original file with the updated content
      Set-Content -Path $file.FullName -Value $updated_content -NoNewline
      Write-Host "Updated: $($file.FullName)"
    } else
    {
      Write-Host "Invalid choice. Please enter '1', '2', or '3'."
      exit 1
    }
  }
}
