#!/bin/bash

# Prompt the user for their choice
echo "Do you want to save the updated files in the 'DD1' folder, overwrite the original files, or exit?"
echo "(1) Save the updated profiles in DD1 folder"
echo "(2) Overwrite the existing files"
echo "(3) Exit"
read choice

if [ "$choice" == "3" ]; then
	echo "Exiting the script."
	exit 0
fi

# Loop over .pws files in the current directory
for file in *.pws; do
	if [ -f "$file" ]; then
		# Read the content of the file
		content=$(cat "$file")

		# Use regex to find the key "FF" and its value
		regex='<FF>([0-9]{2,3})<\/FF>'
		if [[ $content =~ $regex ]]; then
			key_value="${BASH_REMATCH[1]}"
			new_value=$((key_value * 125 / 100)) # Multiply by 1.25

			# Replace the old value with the new value
			updated_content=$(echo "$content" | sed "s|${BASH_REMATCH[0]}|<FF>$new_value</FF>|")

			if [ "$choice" == "1" ]; then
				# Save the updated content to a new file in 'DD1' folder with "updated" after the extension
				if [ ! -d "DD1" ]; then
					mkdir "DD1"
				fi
				echo "$updated_content" >"DD1/${file%.pws}_DD1.pws"
				echo "Updated: DD1/${file%.pws}_DD1.pws"
			elif [ "$choice" == "2" ]; then
				# Overwrite the original file with the updated content
				echo "$updated_content" >"$file"
				echo "Updated: $file"
			else
				echo "Invalid choice. Please enter '1', '2', or '3'."
				exit 1
			fi
		fi
	fi
done
